@@ -1,4 +1,4 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python3
 # Copyright (C) 2015 J.F.Dockes
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -17,12 +17,11 @@
 
 # Transform XML output from xls-dump.py into csv format.
 #
-# Note: this would be difficult to make compatible with python 3 <= 3.4
-# because of the use of % interpolation on what should be bytes.
-# The python2 restriction is not a big issue at this point because
-# msodumper is not compatible with python3 anyway
-# % interpolation for bytes is planned for python 3.5, at which point
-# porting this module will become trivial.
+# Note: this would be difficult to make compatible with python 3 <=
+# 3.4 because of the use of % interpolation on what should be bytes.
+# # % terpolation for bytes is available as of python 3.5, which is
+# the minimum version supported.
+
 
 from __future__ import print_function
 
@@ -32,20 +31,20 @@ import xml.sax
 dtt = True
 
 if dtt:
-    sepstring = "\t"
-    dquote = ''
+    sepstring = b"\t"
+    dquote = b""
 else:
-    sepstring = ","
-    dquote = '"'
-    
+    sepstring = b","
+    dquote = b'"'
+
 class XlsXmlHandler(xml.sax.handler.ContentHandler):
     def __init__(self):
-        self.output = ""
+        self.output = b''
         
     def startElement(self, name, attrs):
         if name == "worksheet":
             if "name" in attrs:
-                self.output += "%s\n" % attrs["name"].encode("UTF-8")
+                self.output += b"%s\n" % attrs["name"].encode("UTF-8")
         elif name == "row":
             self.cells = dict()
         elif name == "label-cell" or name == "number-cell":
@@ -57,7 +56,7 @@ class XlsXmlHandler(xml.sax.handler.ContentHandler):
                 self.cells[int(attrs["col"])] = value
             else:
                 #??
-                self.output += "%s%s" % (value.encode("UTF-8"), sepstring)
+                self.output += b"%s%s" % (value.encode("UTF-8"), sepstring)
         elif name == "formula-cell":
             if "formula-result" in attrs and "col" in attrs:
                 self.cells[int(attrs["col"])] = \
@@ -68,11 +67,11 @@ class XlsXmlHandler(xml.sax.handler.ContentHandler):
             curidx = 0
             for idx, value in self.cells.items():
                 self.output += sepstring * (idx - curidx)
-                self.output += "%s%s%s" % (dquote, value, dquote)
+                self.output += b"%s%s%s" % (dquote, value, dquote)
                 curidx = idx
-            self.output += "\n"
+            self.output += b"\n"
         elif name == "worksheet":
-            self.output += "\n"
+            self.output += b"\n"
 
 
 if __name__ == '__main__':
